//clear all
pause on 
set more off
set matsize 11000

scalar short_zlist=$short_zlist_val

cap prog drop bysmeanw
prog def bysmeanw
 	syntax varname, weight(varname) by(varlist) [rename(name)]
	
 	if "`rename'" == "" local rename = "`varlist'bar"

	tempvar totweight totsum varXweight
	
	bys `by': egen double `totweight' = total((`varlist'<.)*`weight')
	bys `by': egen double `totsum'    = total( `varlist'*`weight')
	g `rename' = `totsum'/`totweight'

end 

// load prices
use "$DATA/laspeyres_state_core.dta", clear
if $use_norm==1 use "$DATA/laspeyres_normgoods_state_core", clear
reshape wide laspeyres_state, i(round state urban) j(expend_type)
forval i=1/4 {
	rename laspeyres_state`i' p`i'
}
save "$DATA/laspeyres_state_reshape.dta", replace

use "$DATA/laspeyres_state_core_2cats.dta", clear
if $use_vis==1 use "$DATA/laspeyres_state_core_2catsVis", clear
if $use_vislux==1 use "$DATA/laspeyres_state_core_2catsVislux", clear
if $use_norm==1 use "$DATA/laspeyres_normgoods_state_core_2cats", clear
reshape wide laspeyres_state, i(round state urban) j(expend_type)
forval i=1/2 {
	rename laspeyres_state`i' P`i'
}
save "$DATA/laspeyres_state_2cats_reshape.dta", replace

if $use_norm==1 {
	use "$DATA/laspeyres_normgoods_state_core_3cats.dta", clear
	reshape wide laspeyres_state, i(round state urban) j(expend_type)
	forval i=1/3 {
		rename laspeyres_state`i' P`i'
	}
	save "$DATA/laspeyres_state_3cats_reshape.dta", replace		
}

// read in consumption data
use "$DATA/years1999_2004.dta", clear
use "$DATA/years1999_2004_sm.dta", clear
g hhid = _n

// update expenditure if normal goods
if $use_norm==1 {
	egen update_exp = rowtotal(food fuel clothing other_nondur)
	replace expenditure = update_exp
}

// possible groups
egen group_district=group(state district)
egen group_round_district=group(state district round)
egen group_round_districtUrb=group(state district round urban)

merge m:1 round state urban using "$DATA/laspeyres_state_reshape.dta"
drop _merge
if `J'!=3 merge m:1 round state urban using "$DATA/laspeyres_state_2cats_reshape.dta"
else			merge m:1 round state urban using "$DATA/laspeyres_state_3cats_reshape.dta"
drop _merge

//make weights comparable across rounds
bys round: egen meanweight=mean(weight)
bys round: replace weight=weight/meanweight
bys round: summ weight

// clean hh chars
replace religion=1 if religion==.
replace socgroup=9 if socgroup==.
g religcaste=(religion==1)*(socgroup<3)+(religion==1)*(socgroup==9)*2+(religion>1)*3
tab religcaste round, col
g scheduled = socgroup==1 | socgroup==2
g hindu = religion==1
g muslim = religion==2
egen hinduXscheduled = group(religion hindu)
g schednh = scheduled==1 & hindu==0
g schedh  = scheduled==1 & hindu==1
g nschedh = scheduled==0 & hindu==1
g nschednh = scheduled==0 & hindu==0
g nonHindu=religion>1

// simplify education categories
recode educ (1 2=1 "Illiterate and Barely Literate") (3 4 5 =2 "Less than HS") (6 7 8=3 "HS or more"), gen(educsimp)

* cutoff_group_size=10, no expenditure trim, cut pairwise comparisons at 0.10 yields passable first stage; scale_factor does not affect GMM
local cutoff_group_size=10
scalar cutoff_expenditure_percentile=99
scalar scale_factor=1

// generate variables
g low_educ = z9==0 & z10==0

// drop top and bottom percentiles of expenditure in each round/state
bys round state: egen expenditure_cutoff=pctile(expenditure),p(99)
drop if expenditure>expenditure_cutoff
drop expenditure_cutoff
bys round state: egen expenditure_cutoff=pctile(expenditure),p(1)
drop if expenditure<expenditure_cutoff

// keep urban houselds smaller than 13 and with head older than 20
keep if urban==1
drop if hhsize>12
gen married=marstat==2
drop if age<20
g hhsizem1=hhsize-1

// winsorize weights
su weight,d
replace weight = r(p95) if weight>r(p95)
replace weight = r(p5) if weight<r(p5)	

g lux=ilux+vlux
g necc=inec+vnec

// education variables
drop if zone==.
tab zone, gen(zone_)
g educmed=educsimp==2
g educhigh=educsimp==3

// scale age (helps numerical performance)
drop if age==.
replace age=age/40

// rename z's so that they can be used in each file
forval i=1/24 {
	rename z`i' demog`i'
}

// landowner dummy
g owns_land = landowned>.005 & landowned<.

egen group_inst=group(state district urban)

if "`group_def'"=="dist"								 		g group=group_round_districtUrb
if "`group_def'"=="fsuXseg"								  g group=geogroup_seg
if "`group_def'"=="fsuXsegXreligXsched"			egen group = group(geogroup_seg religion scheduled)
if "`group_def'"=="fsuXsegXreligXschedXownsland"	egen group = group(geogroup_seg religion scheduled owns_land)
if "`group_def'"=="fsuXsegXreligXschedXehigh"			egen group = group(geogroup_seg religion scheduled educhigh)

if $rand_grp==1 {
	sort round
	sort round state district
	g shuffle = _n
	g rand = runiform()
	sort round rand
	sort round state district rand
	g group_new = group[shuffle]
	replace group = group_new
	drop group_new shuffle rand
}

egen group_round=group(group round) // because group is different in each round, same as group
egen district_round=group(state district round urban)

// make comparision group, so can restrict to sample in other regs
if "`groupComp_def'"=="dist"								 		g groupComp=group_round_districtUrb
if "`groupComp_def'"=="fsuXseg"								  g groupComp=geogroup_seg
if "`groupComp_def'"=="fsuXsegXreligXsched"			egen groupComp = group(geogroup_seg religion scheduled)
if "`groupComp_def'"!="" egen groupComp_round = group(groupComp round)

if short_zlist==1 {	
	global T=7
	
	g z1=hhsizem1/10
	g z2=age/3
	g z3=married
	g z4=.
	g land=exp(demog23)
	replace z4=0 if land<=0.005
	replace z4=ln(land+1) if land>0.005
	g z5=demog24
	g z6=educmed
	g z7=educhigh
	order land, after(z7)
	
	global zlist "z1 z2 z3 z4 z5 z6 z7"
	global zlist_indiv "z1 z2 z3 z4 z5 z6 z7"
	global xzlist_indiv "xz1 xz2 xz3 xz4 xz5 xz6 xz7"
}

if short_zlist==2 {	
	global T=10
	
	g z1=hhsizem1/10
	g z2=age/3
	g z3=married
	g z4=.
	g land=exp(demog23)
	replace z4=0 if land<=0.005
	replace z4=ln(land+1) if land>0.005
	g z5=demog24
	g z6=educmed
	g z7=educhigh
	g z8 = scheduled==1 & hindu==0
	g z9 = scheduled==0 & hindu==0
	g z10 = scheduled==0 & hindu==1
	
	global zlist "z1 z2 z3 z4 z5 z6 z7 z8 z9 z10"
	global zlist_indiv "z1 z2 z3 z4 z5 z6 z7 z8 z9 z10"
	global xzlist_indiv "xz1 xz2 xz3 xz4 xz5 xz6 xz7 xz8 xz9 xz10"
}

if short_zlist==3 {	
	global T=8
	
	g z1=hhsizem1/10
	g z2=age/3
	g z3=married
	g z4=.
	g land=exp(demog23)
	replace z4=0 if land<=0.005
	replace z4=ln(land+1) if land>0.005
	g z5=demog24
	g z6=educmed
	g z7=educhigh
	g z8 = owns_land
	
	global zlist "z1 z2 z3 z4 z5 z6 z7 z8"
	global zlist_indiv "z1 z2 z3 z4 z5 z6 z7 z8"
	global xzlist_indiv "xz1 xz2 xz3 xz4 xz5 xz6 xz7 xz8"
}

if short_zlist==4 {	
	global T=7
	
	g z1=hhsizem1/10
	g z2=age/3
	g z3=married
	g z4=.
	g land=exp(demog23)
	replace z4=0 if land<=0.005
	replace z4=ln(land+1) if land>0.005
	g z5=demog24
	g z6=educmed
	g z7=educhigh
	
	global zlist "z1 z2 z3 z4 z5 z6 z7"
	global zlist_indiv "z1 z2 z3 z4 z5 z6 z7"
	global xzlist_indiv "xz1 xz2 xz3 xz4 xz5 xz6 xz7"
}

if short_zlist==5 {	
	global T=6
	
	g z1=age/3
	g z2=married
	g z3=.
	g land=exp(demog23)
	replace z3=0 if land<=0.005
	replace z3=ln(land+1) if land>0.005
	g z4=demog24
	g z5=educmed
	g z6=educhigh
	order land, after(z6)
	
	global zlist "z1 z2 z3 z4 z5 z6"
	global zlist_indiv "z1 z2 z3 z4 z5 z6"
	global xzlist_indiv "xz1 xz2 xz3 xz4 xz5 xz6"
}

if short_zlist==6 {
	global T=5
	
	g z1=hhsizem1/10
	g z2=p1
	g z3=p2
	g z4=p3
	g z5=p4
	g land=exp(demog23)
	
	global zlist "z1 z2 z3 z4 z5"
	global zlist_indiv "z1"
	global xzlist_indiv "xz1"
	
	drop if land==. | demog24==.	
}

if short_zlist==7 {
	global T=11
	
	g z1=hhsizem1/10
	g z2=age/3
	g z3=married
	g z4=.
	g land=exp(demog23)
	replace z4=0 if land<=0.005
	replace z4=ln(land+1) if land>0.005
	g z5=demog24
	g z6=educmed
	g z7=educhigh
	g z8=p1
	g z9=p2
	g z10=p3
	g z11=p4
	
	global zlist "z1 z2 z3 z4 z5 z6 z7 z8 z9 z10 z11"
	global zlist_indiv "z1 z2 z3 z4 z5 z6 z7"
	global xzlist_indiv "xz1 xz2 xz3 xz4 xz5 xz6 xz7"
}



// drop missings and calculate size of grp
forv j = 1(1)$T {
	drop if z`j'==.
}
bys group_round: egen size_group_round=count(group_round)

// size of comparision group
if "`groupComp_def'"!="" {
	bys groupComp_round: egen size_groupComp_round=count(groupComp_round)	
}

// turn things int oper capita terms if ption flagged
if $meas_pc==1 {
	foreach var in expenditure vlux ilux vnec inec lux necc food fuel clothing other_nondur {
		replace `var' = `var'/hhsize
	}
}
		
// normalize expenditure by overall mean
summ expenditure [aweight=weight]
scalar expenditure_mean=r(mean)
foreach var in expenditure vlux ilux vnec inec lux necc food fuel clothing other_nondur {
	g `var'_norm=`var'/expenditure_mean
}

if $use_norm==0 {
	g pq1=vlux_norm
	g pq2=ilux_norm
	g pq3=vnec_norm
	g pq4=inec_norm
}
else {
	g pq1=food_norm
	g pq2=fuel_norm
	g pq3=clothing_norm
	g pq4=other_nondur_norm	
}
g x=expenditure_norm
g x2=x*x

// make q averages
qui bysort group_round: egen weight_group_round=sum(weight)

forval j=1/4 {
			qui g s`j'=pq`j'/expenditure_norm
			qui g q`j'=pq`j'/p`j'
			qui bysmeanw q`j', weight(weight) by(group_round) rename(qbar`j')
			qui summ q`j' [aweight=weight]
			scalar qallbar`j'=r(mean)
			qui summ s`j' [aweight=weight]
			scalar sallbar`j'=r(mean)
}	

// 2 category consumption
g PQ1=pq1+pq2
g PQ2=pq3+pq4
if $use_vis==1 {
	drop PQ1 PQ2
	g PQ1=pq1+pq3
	g PQ2=pq2+pq4
}
if $use_vislux==1 {
	drop PQ1 PQ2
	g PQ1=pq1
	g PQ2=pq2+pq3+pq4
}
if $use_norm==1 {
	drop PQ1 PQ2
	g PQ1=pq1
	g PQ2=pq2+pq3+pq4
	if `J'==3 {
		drop PQ1 PQ2
		g PQ1=pq1
		g PQ2=pq2
		g PQ3=pq3+pq4
	}
}

forval j=1/2 {
	qui g Q`j'=PQ`j'/P`j'
	qui bysmeanw Q`j', weight(weight) by(group_round) rename(Qbar`j')
}	
if `J'==3 {
	qui g Q`J'=PQ`J'/P`J'
	qui bysmeanw Q`J', weight(weight) by(group_round) rename(Qbar`J')
}

// only scheduled groups (with some of other group)
bys geogroup_seg religion: egen share_sched = mean(scheduled)
if $only_scheduled==1 keep if scheduled==1 & share_sched>0 & share_sched<1

// update group epend wiht other group
if $only_scheduled==2 {
	preserve
		keep if scheduled==0
		keep geogroup_seg religion Qbar* qbar*
		duplicates drop
		tempfile update_exp
		save `update_exp'
	restore
	keep if scheduled==1 & share_sched>0 & share_sched<1
	merge m:1 geogroup_seg religion using `update_exp', update replace keep(3 4 5) nogen
}
drop share_sched

// laysperes_cpi varies by district and round
g local_cpi=p1^sallbar1*p2^sallbar2*p3^sallbar3*p4^sallbar4

// make instruments
// xbarlag is the average x in the same group in other periods, and xbar2lag is its square; x2barlag is the average x2;
//    letting t=1,...,T: ztbarlag is the average zt in other periods; xztbarlag is the average of x*zt in other periods
// measure all the x-stuff in reals, using aggregate laysperes index.
g weight_temp=weight
global instlist ""
g xreal=x/local_cpi
g x_temp=x
g x2_temp=x2
replace x=xreal
replace x2=x*x

// make z x interactions
foreach var of varlist $zlist {
	g x`var'=x*`var'
}

levelsof round, local(roundlist)
foreach var of varlist x x2 $zlist_indiv $xzlist_indiv {
	qui g `var'barlag=.
	foreach rnd of local roundlist {
			qui replace weight_temp=0 if round==`rnd'
			qui bysmeanw `var', weight(weight_temp) by(group_inst) rename(`var'bar`rnd')	
			qui replace `var'barlag=`var'bar`rnd' if round==`rnd'
			qui drop `var'bar`rnd'
			qui replace weight_temp=weight
	}
	global instlist "$instlist `var'barlag"
}

g xbar2lag=xbarlag^2
g rootxbarlag=sqrt(xbarlag)

bysmeanw x, weight(weight) by(group) rename(xbar)	
bysmeanw x2, weight(weight) by(group) rename(x2bar)	
g xbar2=xbar^2
g rootxbar = sqrt(xbar)
foreach var of varlist $zlist_indiv $xzlist_indiv {
	bysmeanw `var', weight(weight) by(group) rename(`var'bar)
	global instlist "$instlist `var'bar"
}

replace x=x_temp
replace x2=x2_temp

// add x terms to inst lsit
global instlist "$instlist xbar2lag rootxbarlag xbar xbar2 x2bar rootxbar"

// only groups of size 3 or more
drop if size_group_round<3
if "`groupComp_def'"!="" drop if size_groupComp_round<3
drop size_group_round
bys group_round: egen size_group_round=count(group_round)

// x x2 are nominal, but xbar, x2bar, xbar2 are real, and are used to predict real quantities qbarj
if `J'==3 local extrakeep "Q3 P3 Qbar3"
if $meas_pc==1 local extrakeep "`extrakeep' hhsize"
keep hhid q1 q2 q3 q4 Q1 Q2 p1 p2 p3 p4 P1 P2 local_cpi x $zlist qbar1-qbar4 Qbar1 Qbar2 group group_round round state district weight size_group*_round weight_group_round $instlist urban land owns_land schednh schedh nschedh nschednh scheduled geogroup hhsize `extrakeep' 

g obs_numi=_n

forval j=1/4 {
	rename q`j' qi`j'
	capture rename Q`j' Qi`j'
}
rename x xi

forval t=1/$T {
	rename z`t' zi`t'
}
rename weight weighti
rename land landi
rename owns_land owns_landi
rename schednh schednhi 
rename schedh schedhi 
rename nschedh nschedhi
rename nschednh nschednhi
g urbani = urban 
rename hhid hhidi
rename scheduled scheduledi
rename hhsize hhsizei

tempfile obs_i
save `obs_i'

// calculate sumstats at hh level
if `make_sumstats'==1 {
	count
	local sumstats_n_obs = r(N)
	
	foreach var of varlist xi Qi1 Qi2 P1 P2 zi1-zi$T {
		qui su `var'
		//local sumstats_row_`var' "`var' & `=round(`=r(mean)',.01)' & `=round(`=r(sd)',.01)' & `=round(`=r(min)',.01)' & `=round(`=r(max)',.01)' "
		local sumstats_row_`var' "`var' & `: di %13.2gc =r(mean)' & `: di %13.2gc =r(sd)' & `: di %13.2gc =r(min)' & `: di %13.2gc =r(max)' "
	}
	local sumstats_row_Qikbar1 "Qikbar1 & & & &"
	local sumstats_row_Qikbar2 "Qikbar2 & & & &"
}

rename obs_numi obs_numk

forval j=1/4 {
	rename qi`j' qk`j'
	capture rename Qi`j' Qk`j'
}
rename xi xk

forval t=1/$T {
	rename zi`t' zk`t'
}
rename weighti weightk
rename landi landk
rename owns_landi owns_landk
rename urbani urbank
rename schednhi schednhik
rename schedhi schedhk
rename nschedhi nschedhk
rename nschednhi nschednhk
rename scheduledi scheduledk
rename hhsizei hhsizek
drop geogroup

// combine into pairs within groups
joinby group_round using "`obs_i'"
drop if obs_numi==obs_numk

// generate exclusive averages qikbarj, of quantities (not spending)
forval j=1/4 {
	g qikbar`j'=(weight_group_round*qbar`j'-weighti*qi`j'-weightk*qk`j')/(weight_group_round-weighti-weightk)
	capture g Qikbar`j'=(weight_group_round*Qbar`j'-weighti*Qi`j'-weightk*Qk`j')/(weight_group_round-weighti-weightk)
}

// summary stats tables
if `make_sumstats'==1 {
	count
	local sumstats_n_obs_pair = r(N)
	
	cap file close sumstat
		file open sumstat using "$OUTPUT/consumption_sumstats.tex", write replace
		file write sumstat "\begin{table}[htbp]\centering" _n
		file write sumstat "\def\sym#1{\ifmmode^{#1}\else\(^{#1}\)\fi}" _n
		file write sumstat "\caption{Summary statistics for consumption data}\label{tab:sumstats}" _n
		file write sumstat "\begin{tabular}{lcccccccc}" _n
		file write sumstat "\toprule" _n
		file write sumstat "& \multicolumn{4}{c}{Observations } & \multicolumn{4}{c}{Pairs }\tabularnewline" _n
		file write sumstat "& \multicolumn{4}{c}{ (N=`: di %13.0gc `sumstats_n_obs'')} & \multicolumn{4}{c}{ (N=`: di %13.0gc `sumstats_n_obs_pair'')}\tabularnewline" _n
		file write sumstat "\cmidrule(lr){2-5}\cmidrule(lr){6-9}  & Mean  & SD  & Min  & Max  & Mean  & SD  & Min  & Max\tabularnewline" _n
		file write sumstat "\midrule" _n
		
		foreach var of varlist xi Qi1 Qi2 Qikbar1 Qikbar2 P1 P2 zi1-zi$T {
			qui su `var'
			//local sumstats_row_`var' "`sumstats_row_`var'' & `=round(`=r(mean)',.01)' & `=round(`=r(sd)',.01)' & `=round(`=r(min)',.01)' & `=round(`=r(max)',.01)' "
			local sumstats_row_`var' "`sumstats_row_`var'' & `: di %13.2gc =r(mean)' & `: di %13.2gc =r(sd)' & `: di %13.2gc =r(min)' & `: di %13.2gc =r(max)' \\"
			file write sumstat "`sumstats_row_`var''" _n
		}
		
		file write sumstat "\bottomrule" _n     
		file write sumstat "\multicolumn{9}{p{.5\hsize}}{\footnotesize Table reports summary statistics for estimation sample.}\\ " _n
		file write sumstat "\end{tabular}" _n 
		file write sumstat "\end{table}" _n 
		file close sumstat			
		BREAK
}

// constant for estimation
g one=1
egen state_district_round=group(state district urban round)
egen state_district=group(state district)

// keep only thick round
keep if round==61




