clear
set more off
pause on

global OUTPUT "/Volumes/APPLE HDD/Dropbox/School/Krishna/Indian/replication/exhibits"
global DATA 	"/Volumes/APPLE HDD/Dropbox/School/Krishna/Indian/replication/data"
//global OUTPUT "/Users/Sam/Dropbox/School/Krishna/Indian/replication/exhibits"
//global DATA 	"/Users/Sam/Dropbox/School/Krishna/Indian/replication/data"

global demolist "age_est sex hhsize_est married educ_prim educ_sec"

use "$DATA/values_combined", clear



// make cpi adjusted nonweighted expenditure
	replace  mean_exp_tot_relig_small = mean_exp_tot_relig_small/1000
	g mean_exp_tot_relig_small_cpi1 = mean_exp_tot_relig_small/(cpi1)
	g mean_exp_tot_relig_small_cpi2 = mean_exp_tot_relig_small/(cpi2)
	g mean_exp_tot_relig_small_cpi3 = mean_exp_tot_relig_small/(cpi3)

	replace  mean_exp_tot_relig_small_inc = mean_exp_tot_relig_small_inc/1000
	g mean_exp_tot_rel_sml_inc_cpi1 = mean_exp_tot_relig_small_inc/(cpi1)
	g mean_exp_tot_rel_sml_inc_cpi2 = mean_exp_tot_relig_small_inc/(cpi2)
	g mean_exp_tot_rel_sml_inc_cpi3 = mean_exp_tot_relig_small_inc/(cpi3)
	
	//replace weight_relig_small=1
	cap g one=1
	g weight_relig_small99 = weight_relig_small
	su weight_relig_small99, d
	replace weight_relig_small99 = r(p99) if weight_relig_small99>r(p99) & weight_relig_small99<.
	
	g weight_relig_small95 = weight_relig_small
	su weight_relig_small95, d
	replace weight_relig_small95 = r(p95) if weight_relig_small95>r(p95) & weight_relig_small95<.


	label var income_imputed_cpi1 "Imputed expenditure"
	label var mean_exp_tot_relig_small_cpi1 "Group expenditure"
	label var mean_exp_tot_rel_sml_inc_cpi1 "Group expenditure"
	label var mean_exp_tot_relig_small "Group expenditure (1000 rupees)"
	
	// make interactions
	su income_imputed_cpi1 if year>2001,d
	g income_above = income_scale>5
	g income_below = income_scale<=5
	
	g satis_sd_norm = satis_sd
	su satis_sd_norm if group!=. & year>2001
	replace satis_sd_norm = (satis_sd_norm-r(mean))/r(sd)
	
	g income_cpi1Xabove= income_imputed_cpi1*income_above
	g groupinc_cpi1Xabove = mean_exp_tot_rel_sml_inc_cpi1*income_above
	label var income_cpi1Xabove 		"Expenditure X above median"
	label var groupinc_cpi1Xabove 	"Group expenditure X above median"	
	
	g income_cpi1Xbelow = income_imputed_cpi1*income_below
	g groupinc_cpi1Xbelow = mean_exp_tot_rel_sml_inc_cpi1*income_below
	label var income_cpi1Xbelow 		"Expenditure X below median"
	label var groupinc_cpi1Xbelow 	"Group expenditure X below median"
	
	g mean_exp_tot_relig_smallXrich = mean_exp_tot_relig_small*(income_scaleD4==1 | income_scaleD5==1)
	label var mean_exp_tot_relig_smallXrich "Group expend X top 2 quintiles"
	
	local sample "if year>2001"
	local sample ""
	
	g use_ob = 1 
	foreach var of varlist satis_sd_norm income_scaleD*      mean_exp_tot_relig_small      $demolist group_rel year {
		replace use_ob = 0 if `var'>=.
	}
	local sample "if use_ob==1"
	
	eststo clear
	eststo: xi: reg 	 satis_sd_norm 		 income_scaleD*      mean_exp_tot_relig_small      					 i.group_rel i.year `sample', cluster(group_rel) 
		su satis_sd_norm if e(sample)
		estadd scalar depmean = r(mean)
		estadd scalar depsd = r(sd)
	eststo: xi: reg 	 satis_sd_norm 		 income_scaleD*      mean_exp_tot_relig_small      $demolist i.group_rel i.year `sample', cluster(group_rel) 
		su satis_sd_norm if e(sample)
		estadd scalar depmean = r(mean)
		estadd scalar depsd = r(sd)
	eststo: xi: reg 	 satis_sd_norm 		 income_scaleD* 		 mean_exp_tot_relig_small mean_exp_tot_relig_smallXrich      $demolist i.group_rel i.year `sample', cluster(group_rel) 
		su satis_sd_norm if e(sample)
		estadd scalar depmean = r(mean)
		estadd scalar depsd = r(sd)
	eststo: xi: ologit satis5 					 income_scaleD*      mean_exp_tot_relig_small     					 i.group_rel i.year `sample', cluster(group_rel) 
		su satis_sd_norm if e(sample)
		estadd scalar depmean = r(mean)
		estadd scalar depsd = r(sd)
	eststo: xi: ologit satis5 					 income_scaleD*      mean_exp_tot_relig_small      $demolist i.group_rel i.year `sample', cluster(group_rel) 
		su satis_sd_norm if e(sample)
		estadd scalar depmean = r(mean)
		estadd scalar depsd = r(sd)
	eststo: xi: ologit satis5 		 			 income_scaleD* 		 mean_exp_tot_relig_small mean_exp_tot_relig_smallXrich      $demolist i.group_rel i.year `sample', cluster(group_rel) 
		su satis_sd_norm if e(sample)
		estadd scalar depmean = r(mean)
		estadd scalar depsd = r(sd)
		
	esttab using "$OUTPUT/SatisTableScale.tex", /// 
		star(* 0.10 ** 0.05 *** 0.01) label ///
		nomtitle booktabs ///
		keep(income_scaleD* 		 mean_exp_tot_relig_small mean_exp_tot_relig_smallXrich) ///
		title("Satisfaction on household and peer income \label{SWB}") se(2) b(2) num  ///
		indicate("Controls = age_est") ///
		stats(N , fmt(%15.0fc) labels("Observations")) ///
		mgroups("OLS (SDs)" "Ordered logit", pattern(1 0 0 1 0 0) span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}) ) /// 
		postfoot("\bottomrule \multicolumn{7}{p{0.85\hsize}}{\footnotesize " ///
				 "Dependent variable as noted in column header, in SD. Subjective well being data " ///
				 "from World Values Survey, imputated group income from NSS. Peer groups defined as intersection " ///
				 "of state and religion (Hindu and non-Hindu)." ///
				 "Controls include household size, age, sex, marital status and education. " ///
				 "All columns include year fixed effects. " ///
				 "Standard errors in parentheses and " ///
				 "clustered at the group level. \sym{*}~\(p<0.10\), \sym{**}~\(p<0.05\)," ///
				 " \sym{***}~\(p<0.01\).}\\ \end{tabular} \end{table}") ///
		replace	
		
		
eststo clear
estpost summarize income_scaleD*      mean_exp_tot_relig_small      $demolist ///
				  `sample', d listwise

esttab using "$OUTPUT/SWB_sumstats_20200404",  ///
	cells("mean(fmt(%15.2g)) sd(fmt(%15.2g)) min(fmt(%15.2g)) max(fmt(%15.2g))")  ///
	replace label booktabs style(tex) collabels("~Mean~" "~SD~" "~~Min~" "~Max~") ///
	title("Subjective well-being summary statistics\label{tab:SwbSummary}") ///
	nonum ///
	postfoot(`"\bottomrule \multicolumn{5}{p{.62\hsize}}{\footnotesize "' ///
	 `"Life satisfaction variable from World Values Survey. Participants were asked "' ///
	 `" \`\`All things considered, how satisfied are you with your life as a whole "' ///
	 `"these days?" and asked to point to a position on a ladder. Coded as 1-5 in 2001 and "' ///
	 `"2006, and 1-10 in 2014. We collapsed to a 1-5 scale in 2014. "' ///
	 `"Group income measured in thousands of Rs/month. "' ///
	 `"}\\ \end{tabular} \end{table}"') 		
		
